@@ -9,6 +9,8 @@ requires 'child_finalize_hook';
 requires 'parent_setup_hook';
 requires 'parent_finalize_hook';
 requires 'build_code_args';
+requires 'receive_child_result';
+requires 'receive_child_error';
 
 1;
 
