@@ -151,6 +151,10 @@ sub build_code_args {
 
 sub parent_setup_hook {}
 sub child_finalize_hook {}
+sub receive_child_result {}
+sub receive_child_error {}
+
+__PACKAGE__->meta->make_immutable;
 
 1;
 
