@@ -113,6 +113,10 @@ sub child_setup_hook {
 sub build_code_args {}
 sub child_finalize_hook {}
 sub parent_setup_hook {}
+sub receive_child_result {}
+sub receive_child_error {}
+
+__PACKAGE__->meta->make_immutable;
 
 1;
 
